@@ -96,20 +96,22 @@ class Video(DeeplabelBase):
     def validate_url(cls, value, values):
         """
         Validate that either video_url or video_urls.source.url exists
+        Since videoUrl can't be updated anymore, since it's deprecated,
+        first check if videoUrls.source.url exists, and use that,
+        else look for videoUrl
         Refer https://github.com/samuelcolvin/pydantic/issues/832#issuecomment-534896056
         """
-        # If video_url key is empty
-        if not isinstance(value, str):
-            # video_urls.source.url
-            try:
-                source_url = values.get('video_urls',{}).source.url
-            except:
-                # should have either of the two
-                raise DeeplabelValueError(f"Video {values['video_id']} neither has video_url nor video_urls.source.url")
-            # set video_url = video_urls.source.url
-            return source_url
-        # keep video_url as is if it exists
-        return value
+        # video_urls.source.url
+        try:
+            source_url = values.get('video_urls',{}).source.url
+        except:
+            # should have either of the two
+            # If video_url key is empty
+            if isinstance(value, str):
+                return value
+            raise DeeplabelValueError(f"Video {values['video_id']} neither has video_url nor video_urls.source.url")
+        # set video_url = video_urls.source.url
+        return source_url
 
     @classmethod
     def _from_search_params(
