@@ -17,7 +17,7 @@ class DetectionType(Enum):
 
 
 class Detection(DeeplabelBase):
-    is_reviewed: bool
+    is_reviewed: Optional[bool]
     type: DetectionType
     bounding_box: Optional[BoundingBox]
     polygon:Optional[Polygon]
