@@ -3,6 +3,7 @@ from deeplabel.exceptions import InvalidIdError
 from deeplabel.basemodel import DeeplabelBase, MixinConfig
 import deeplabel.label.folders
 import deeplabel.label.videos
+import deeplabel.label.label_maps
 import deeplabel.client
 import deeplabel
 
@@ -46,7 +47,7 @@ class Project(DeeplabelBase):
     @property
     def image_datasets(self):
         return deeplabel.label.folders.RootFolder(
-            projectId=self.project_id,
+            project_id=self.project_id,
             type=deeplabel.label.folders.FolderType.GALLERY,
             client=self.client
         )
@@ -54,7 +55,11 @@ class Project(DeeplabelBase):
     @property
     def video_datasets(self):
         return deeplabel.label.folders.RootFolder(
-            projectId=self.project_id,
+            project_id=self.project_id,
             type=deeplabel.label.folders.FolderType.VIDEO,
             client=self.client
         )
+    
+    @property
+    def label_map(self)->List["deeplabel.label.label_maps.LabelMap"]:
+        return deeplabel.label.label_maps.LabelMap.from_search_params({'projectId':self.project_id}, self.client)
